@@ -1,12 +1,17 @@
-package NG::Log;
+package Log;
 use strict;
 use warnings;
 use autodie;
 use 5.010;
-use base qw(NG::Object);
-use NG::Hashtable;
-use NG::Array;
-use NG::Log::IPMatcher;
+use base qw(Object);
+use Hashtable;
+use Array;
+use Geo::IP;
+
+sub new {
+    my $pkg = shift;
+    return bless {}, $pkg;
+}
 
 =head1 process_log
 my $logpath = '/opt/graphite/storage/log/webapp/access.log';
@@ -24,13 +29,9 @@ sub process_log {
     open my $fh, '<', $logpath;
     while (<$fh>) {
         chomp;
-        my $lines = NG::Array->new( split( $sep, $_ ) );
+        my $lines = Array->new( split( $sep, $_ ) );
         $cb->($lines);
     }
 }
 
-sub geo_ip {
-    ...
-}
-
 1;
