@@ -1,4 +1,4 @@
-package NG::Object;
+package Object;
 
 use strict;
 use warnings;
@@ -14,8 +14,4 @@ sub dump {
     return Dumper($self);
 }
 
-sub meta {
-    { attrs => [], methods => ['dump'] }
-}
-
 1;
